==> cxf-testutils-2.0.6.3-fuse-sources.jar: org/apache/type_test/types3/OccuringStruct2.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringStruct2 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStruct2">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;sequence maxOccurs="5" minOccurs="2">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/sequence>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStruct2", propOrder = {
    "varFloat",
    "varIntAndVarString"
})
public class OccuringStruct2 {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected float varFloat;
    @XmlElements({
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types3", required = true, type = String.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class)
    })
    protected List<Serializable> varIntAndVarString;

    /**
     * Gets the value of the varFloat property.
     * 
     */
    public float getVarFloat() {
        return varFloat;
    }

    /**
     * Sets the value of the varFloat property.
     * 
     */
    public void setVarFloat(float value) {
        this.varFloat = value;
    }

    /**
     * Gets the value of the varIntAndVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntAndVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntAndVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getVarIntAndVarString() {
        if (varIntAndVarString == null) {
            varIntAndVarString = new ArrayList<Serializable>();
        }
        return this.varIntAndVarString;
    }

}

==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/type_test/types3/OccuringStruct2.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringStruct2 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStruct2">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;sequence maxOccurs="5" minOccurs="2">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/sequence>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStruct2", propOrder = {
    "varFloat",
    "varIntAndVarString"
})
public class OccuringStruct2 {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected float varFloat;
    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types3", required = true, type = String.class)
    })
    protected List<Serializable> varIntAndVarString;

    /**
     * Gets the value of the varFloat property.
     * 
     */
    public float getVarFloat() {
        return varFloat;
    }

    /**
     * Sets the value of the varFloat property.
     * 
     */
    public void setVarFloat(float value) {
        this.varFloat = value;
    }

    /**
     * Gets the value of the varIntAndVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntAndVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntAndVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarIntAndVarString() {
        if (varIntAndVarString == null) {
            varIntAndVarString = new ArrayList<Serializable>();
        }
        return this.varIntAndVarString;
    }

}
